function [PluieEPSAT, Temps, Longitudes, Latitudes] = EPSATread(ncfilesset, fullfilename)

%EPSAT lit le fichier NetCDF de l'algorithme EPSAT du jour souhaite
%pour en sortir les variables (temps, longitudes et latitudes) ainsi que
%les donnees de l'estimation des precipitations.

%
%+
%
% ===========
% EPSATread.m
% ===========
%
% .. function:: EPSATread(fullfilename)
%
% DESCRIPTION
% ===========
%
% - Donnees d'entrees :
%
%   * ncfilesset (en caracteres) : Type de fichier NetCDF que l'on cherche,
%     'normal' ou 'extracted'.
%   * fullfilename : Chemin d'acces au fichier pour la date desiree.
%
% - Donnees de sorties :
%
%   * Temps : Variable de temps du fichier NetCDF.
%   * Longitudes : Variable de longitudes.
%   * Latitudes : Variable de latitudes.
%   * PluieEPSAT : Donnees brutes de l'estimation des precipitations dont
%     les dimensions sont respectivement, temps, longitudes et latitudes.
%
% lecture du fichier NetCDF de l'algorithme EPSAT du jour souhaite pour en
% sortir les variables (temps, longitudes et latitudes) ainsi que les
% donnees de l'estimation des precipitations.
%
% EXAMPLES
% ========
%
% Voir la 'demo'.
%
% SEE ALSO
% ========
%
% :ref:`data_epsat`
%
% :ref:`varamma_startup.m`
%
% :func:`EPSATbuildfullfilename`
%
% :func:`cumulEPSAT_day`
% :func:`compar_tbnoyau_disp`
% :func:`compar_tbnoyau_image`
% :func:`compar_tbseuil_histo`
% :func:`compar_tbseuil_image`
% :func:`histo_cumulEPSAT`
%
% TODO
% ====
%
% test if existing input file
%
% handling of missing values
%
% pourquoi les donnes sont dans des variables differentes entre extracted et normal
%
% unit de temps : jaclod m'a scrontch la revision 291 !!
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/EPSATread.m $
%
% - fplod 20110829T133532Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * revision if netcdf_open_available = 1
%
% - fplod 20110805T071227Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * display fullfilename
%   * add demo for extracted file
%   * move permutation location changed by jaclod (why ?)
%   * restore scale factor and missing value handling remove by jaclod (why ?)
%
% - jaclod 2011-07-26
%
%   * Revision de la documentation et des commentaires.
%
% - jaclod 2011-07-21
%
%   * Lecture des fichiers 'extracted' sur Matlab Cratos.
%
% - jaclod 2011-07-13
%
%   * Changement des arguments d'entrees 'Annee', 'Mois', 'Jour' par
%     'fullfilename'. Celui-ci peut-etre cree par 'EPSATbuildfullfilename'.
%   * Externalisation de la selection de donnees (voir la fonction
%     'extractedmatrixdata').
%   * Ajout du facteur d'echelle.
%
% - pinsard 2011-05-20T09:10:34Z loholt1.ipsl.polytechnique.fr (Linux)
%
%   * demo on 20060801 like other datasets
%   * location f(yyyy,mm)
%
% - fplod 20110310T100031Z
%
%   * fix misplaced clear statements
%
% - fplod 20110309T122613Z
%
%   * replace ispc() criteria by test on netcdf_open_available to choose
%     netcdf instruction set
%   * permute array after reading 3D data if netcdf.getVar was used
%   * close netcdf opened file
%   * PlueEPSAT int -> double
%
% - fplod 20110304T105348Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * minimal modif to be used on zeus with matlab R2007a :
%     path of dataset, netcdf reading tools
%
%     ok also on octave 3.2.4 on cratos (no netcdf on zeus !!)
%
% - fplod 20110304T082754Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * fix rst header
%
% - jaclod 2011-03-02
%
%   * Ajout de la documentation et de la demonstration.
%
% - jaclod 2011-02-25
%
%   * Creation.
%
%-

% Appel de la variable global 'netcdf_open_available'.
global netcdf_open_available

usage='[PluieEPSAT, Temps, Longitudes, Latitudes] = EPSATread(ncfilesset, fullfilename)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% Ouverture du fichier selon l'installation.
if netcdf_open_available
   ncid = netcdf.open(fullfilename, 'NC_NOWRITE');
else
   ncid = netcdf(fullfilename, 'nowrite');
end
disp(['iii : opening for reading ', fullfilename]);

clear fullfilename

% Recuperation des variables selon l'installation et le type de fichier.
if netcdf_open_available

    switch ncfilesset

        case 'normal'

            Temps = netcdf.getVar(ncid,0);
            Latitudes = netcdf.getVar(ncid,1);
            Longitudes = netcdf.getVar(ncid,2);

        case 'extracted'

            Temps = netcdf.getVar(ncid,11);
            Latitudes = netcdf.getVar(ncid,9);
            Longitudes = netcdf.getVar(ncid,10);

        otherwise

            error('La variable ncfilesset doit etre ''normal'' ou ''extracted''.');

    end

else

   Temps = ncid{'time'}(:);
   Latitudes = ncid{'lat'}(:);
   Longitudes = ncid{'lon'}(:);

end

% Recuperation des donnees de precipitation selon l'installation.
if netcdf_open_available

   switch ncfilesset

       case 'normal'

           PluieEPSAT = netcdf.getVar(ncid,11);

           % Application du facteur d'echelle.
           PluieEPSAT = double(PluieEPSAT) * double(netcdf.getAtt(ncid,11,'scale_factor'));
           % permute to output array with
           % dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
           PluieEPSAT = permute(PluieEPSAT,[3 1 2]);

       case 'extracted'

           PluieEPSAT = netcdf.getVar(ncid,8);

           % Application du facteur d'echelle.
           PluieEPSAT = double(PluieEPSAT) * double(netcdf.getAtt(ncid,8,'scale_factor'));
           % permute to output array with
           % dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
           PluieEPSAT = permute(PluieEPSAT,[3 1 2]);

       otherwise

           % Un message d'erreur a deja ete envoye auparavant, on ne peut
           % se retrouver a nouveau dans ce cas.

   end

else

   PluieEPSAT = ncid{'data'}(:,:,:);
   % Set missing value to NaN
   PluieEPSAT(PluieEPSAT==ncid{'data'}.missing_value)=NaN;
   % apply scale_factor and add_offset
   PluieEPSAT=ncid{'data'}.scale_factor(:)*PluieEPSAT;
   % permute to output array with
   % dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
   PluieEPSAT = permute(PluieEPSAT,[1 3 2]);

end

% Fermeture de la lecture.
if netcdf_open_available

   netcdf.close(ncid);

end

clear ncid

end

%!demo
%! % From real file :file:`${PROJECT_ID}/EPSAT/2006/08/surf-rr_epsat-smulti-sat_010d_30min_20060801_v3.1-02c.nc`::
%! close all
%! clear all
%! varamma_startup;
%! more off
%! ncfilesset = 'normal';
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! [fullfilename] = EPSATbuildfullfilename(ncfilesset, Annee, Mois, Jour);
%! [PluieEPSAT, Temps, Longitudes, Latitudes] = EPSATread(ncfilesset, fullfilename);
%! whos

%!demo
%! % From real file :file:`${PROJECT_ID}/EPSAT/extracted/2006/08/extracted-surf-rr_epsat-sg_multi-sat_010d_30min_20060801_v3.1-02c.nc
%! close all
%! clear all
%! varamma_startup;
%! more off
%! ncfilesset = 'extracted';
%! Annee = '2006';
%! Mois = '08';
%! Jour = '01';
%! [fullfilename] = EPSATbuildfullfilename(ncfilesset, Annee, Mois, Jour);
%! ncfilesset = 'extracted';
%! [PluieEPSAT, Temps, Longitudes, Latitudes] = EPSATread(ncfilesset, fullfilename);
%! whos
