#! /bin/sh
#+
#
# .. program:: cat_clim_ecmwf.sh
#
# =================
# cat_clim_ecmwf.sh
# =================
#
# ----------------------------
# build ECMWF climatology file
# ----------------------------
#
# SYNOPSIS
# ========
#
# ``cat_clim_ecmwf.sh``
#
#
# DESCRIPTION
# ===========
#
# Build ECMWF climatology file
# of relative humidity
# ++using mean daily file by year and reduce geographical domain
# ++to [60  W, 50  E] [30  S, 45  N].
#
#
# .. only:: man
#
#    Figure is visible on PDF and HTML documents only.
#
# .. only:: html or latex
#
#     .. graphviz::
#
#        digraph cat_clim_ecmwf {
#           graph [
#           rankdir="TB",
#           ]
#
#           ecmwf_t1 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/geopt.yyyymm.aph.nc"];
#           ecmwf_t2 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/r.yyyymm.aph.nc"];
#
#           ecmwf_t3 [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/climato.r.yyyy.yyyy.6TU.nc"];
#           ecmwf_t4 [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/CAT.r.yyyy.yyyy.6TU.nc"];
#           
#           cat_clim_ecmwf [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/cat_clim_ecmwf.sh"
#           label="${PROJECT}/src/cat_clim_ecmwf.sh"];
#           
#           {ecmwf_t1 ecmwf_t2} -> {cat_clim_ecmwf} -> {ecmwf_t3 ecmwf_t4};
#           
#           }
#           
# EXAMPLES
# ========
#
# To build ECMWF climatology ::
#
#  $ cat_clim_ecmwf.sh
#
# COMMENTS
# ========
#
# If yearmin and yearmax are the same one can compare input and output files
# like this:
#
#
# For yearmin=yearmax=2000::
#
#  $ cdo diffv ${PROJECT_ID}/++_ng.nc \
#              ${PROJECT_OD}/ecmwf.day.mean_climato_ng.nc
#
#
# There must be a difference because 2000 is a leap year.
#
#
# For yearmin=yearmax=2001::
#
#  $ cdo diffv ${PROJECT_ID}/ecmwf.day.mean_2001_ng.nc \
#              ${PROJECT_OD}/ecmwf.day.mean_climato_ng.nc
#
# There must be no difference on values of ecmwf and info fields ++  vrifier
#
# SEE ALSO
# ========
#
# TODO
# ====
#
# .. todo::
#
#    option debug/verbose
#
#    gestion log
#
#    vrification accs filein
#
#    pb levels operationel vs reanalyse
#
#    29 fvrier
#
# EVOLUTIONS
# ==========
#
# $Id$
#
#
# - fplod 20100702T081256Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add graph (from varamma/notes/varamma_etape6.dot)
#
# - fplod 20100318T074505Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * unset
#
# - fplod 2008-11-20T09:36:58Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation from /homedata/eymard/scripts/script_cat_clim_ECMWF3d
#
#-
#
# main program
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo " www : no specific posix checking"
   ;;
   *)
      set -o posix
   ;;
esac
unset system
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command}"
#
# ++ test si ncks available
# ++ test si ncdump available
#
yearmin=2000
yearmax=2007
#
yearmin=2000 #++ pour debug
yearmax=2000 #++ pour debug
#
minargcount=0
if [ ${#} -lt ${minargcount} ]
then
   echo "eee : not enought arguments"
   echo "${usage}"
   exit 1
fi
unset minargcount
#
while [ ${#} -gt 0 ]
do
   case ${1} in
      -h)
         echo "${usage}"
         exit 0
      ;;
      *)
         # other choice
         echo "eee : unknown option ${1}"
         echo "${usage}"
         exit 1
      ;;
   esac
   # next flag
   shift
done
unset usage
#
# check for ${PROJECT_LOG} definition
if [ "${PROJECT_LOG}" = "" ]
then
   echo " eee : \${PROJECT_LOG} not defined"
   exit 1
fi
#
# check for ${PROJECT_LOG} existence
if [ ! -d ${PROJECT_LOG} ]
then
   echo " eee : ${PROJECT_LOG} not found"
   exit 1
fi
#
# check for permission access on PROJECT_LOG
if [ ! -x ${PROJECT_LOG} ]
then
   echo " eee : ${PROJECT_LOG} not reachable"
   exit 1
fi
#
# check for write permission on PROJECT_LOG
if [ ! -w ${PROJECT_LOG} ]
then
   echo " eee : ${PROJECT_LOG} not writable"
   exit 1
fi
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
#++echo "runtime = ${log_date}" 1>> ${log}
#
# ++ PROJECT_ID
# ++ PROJECT_OD
#
# check for input files
monthmin=1
monthmax=12
listyear=""
iyear=${yearmin}
while [ ${iyear} -le ${yearmax} ]
do
   cyear=$(printf "%4.4d" ${iyear})
   imonth=${monthmin}
   nmonth=0
   listmonth=" "
   while [ ${imonth} -le ${monthmax} ]
   do
      cmonth=$(printf "%2.2d" ${imonth})
      if [ ${iyear} -le 2001 ]
      then
         filein=${PROJECT_ID}/z${cyear}${cmonth}_ng.nc
      else
         filein=${PROJECT_ID}/geopt${cyear}${cmonth}_ng.nc
      fi
      if [ ! -r ${filein} ]
      then
         echo "iii : ${filein} not accessible"
      else
         #++   isleap
         fileout=${PROJECT_OD}/$(basename ${filein} .nc).6TU.nc
         # Unpack : geo_value = var*scale_factor + add_offset
         jpt=$( ncdump -h ${filein} | grep UNLIMITED )
         jpt=${jpt##*\(}
         jpt=${jpt%%  currently*}
         ncks -d lat,-40.,50. -d level,100.,925. -d time,1,$(( $jpt - 3 )),4 $filein ${fileout}_1
         unset jpt
         unset filein
         #
         ncpdq -U ${fileout}_1 ${fileout}
         # ++ test ok
         rm ${fileout}_1
         listmonth="${listmonth} ${fileout}"
         nmonth=$(( ${nmonth} + 1 ))
      fi
      imonth=$(( ${imonth} + 1 ))
   done
   # concatenation of monthly files
   listyear="${listyear} ${PROJECT_OD}/catr.${cyear}.6TU.nc"
   # ++ si un aucun ++ si un seul cp au lieu de ncrcat
   # test if more than one file within current year
   case ${nmonth} in
      0)
         echo "eee : nothing to concatenate for year ${iyear}"
         #++ exit 1
      ;;
      1)
         cp ${listmonth} ${PROJECT_OD}/catr.${cyear}.6TU.nc
         listyear="${listyear} ${PROJECT_OD}/catr.${cyear}.6TU.nc"
      ;;
      *)
         ncrcat ${listmonth} ${PROJECT_OD}/catr.${cyear}.6TU.nc
         listyear="${listyear} ${PROJECT_OD}/catr.${cyear}.6TU.nc"
      ;;
   esac
   iyear=$(( ${iyear} + 1 ))
done
unset iyear
#
# build fileout
# based on the first file of the serie (ie yearmin) ++ ou vraie premiere anne
# (ie si yearmin 1900 pas de donnes 1900)
fileout=${PROJECT_OD}/CAT.r.${yearmin}.${yearmax}.6TU.nc
if [ -f ${fileout} ]
then
   echo "eee : ${fileout} already exists"
   unset fileout
   unset yearmin
   unset yearmax
   exit 1
fi
#
# concatenation of yearly files
ncrcat ${listyear} ${fileout}
status_ncrcat=${?}
if [ ${status_ncrcat} -ne 0 ]
then
   echo "eee : pb with ncrcat"
   exit 1
fi
unset status_ncrcat
#
# build fileout
# based on the first file of the serie (ie yearmin) ++ ou vraie premiere anne
# (ie si yearmin 1900 pas de donnes 1900)
fileout=${PROJECT_OD}/climato.r.${yearmin}.${yearmax}.6TU.nc
if [ -f ${fileout} ]
then
   echo "eee : ${fileout} already exists"
   exit 1
fi
unset yearmin
unset yearmax
#
# mean of yearly files
ncea ${listyear} ${fileout}
status_ncea=${?}
if [ ${status_ncks} -ne 0 ]
then
   echo "eee : pb with ncea"
   exit 1
fi
unset status_ncea
#
unset listyear
unset fileout
#
# clean
rm ${PROJECT_OD}/M++
rm ${PROJECT_OD}/cat++
#
# end
unset log
exit 0
