function [lon_station, lat_station, altitude_station ] = get_station_geolocation(station, lon_value, lat_value, altitude_value, station_value)

%GET_STATION_GEOLOCATION returns geolocation of a given station

%
%+
%
% =========================
% get_station_geolocation.m
% =========================
%
% .. function:: get_station_geolocation(station, lon_value, lat_value, altitude_value, station_value)
%
% DESCRIPTION
% ===========
%
%    :param station: station we are looking for
%    :type station: string
%    :raise station: required
%
%    :param lon_value: longitude array
%    :type lon_value: 1D array of floats
%    :raise lon_value: required
%
%    :param lat_value: latitude array
%    :type lat_value: 1D array of floats
%    :raise lat_value: required
%
%    :param altitude_value: altitude array
%    :type altitude_value: 1D array of floats
%    :raise altitude_value: required
%
%    :param station_value: station array
%    :type station_value: 1D cell array of strings
%    :raise station_value: required
%
% Look for ``station`` in ``station_value`` array and return associated latitude, longitude and altitude.
%
% If no match found or multiple matches found, returned values are set to NaN.
%
% EXAMPLES
% ========
%
% see demos
%
% SEE ALSO
% ========
%
% :ref:`guide data station pluviometer <data_station_pluviometer>`
%
% :func:`simul_station`
% :func:`read_station`
%
% TODO
% ====
%
% check arguments (type, size, value)
%
% status de retour
%
% description du rsultat en ReST
%
% EVOLUTIONS
% ==========
%
% $Id$
%
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/get_station_geolocation.m $
%
% - fplod 20110223T150200Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add demo and test
%   * fix error in examples
%
% - fplod 20110221T160754Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * remove code_value from parameters
%
% - fplod 20110221T110904Z zeus.locean-ipsl.upmc.fr (Linux)
%
%   * creation
%
%-
%
% init of results
lon_station=NaN;
lat_station=NaN;
altitude_station=NaN;
%
usage='[lon_station, lat_station, altitude_station ] = get_station_geolocation(station, lon_value, lat_value, altitude_value, station_value)';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('lon_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg lon_value ' arg_info.class]);
   whos lon_value
   error(usage);
end
clear arg_info
%
if ~isvector(lon_value)
   disp('arg lon_value must be a vector');
   error(usage);
end
%
arg_info=whos('lat_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg lat_value ' arg_info.class]);
   whos lat_value
   error(usage);
end
clear arg_info
%
if ~isvector(lat_value)
   disp('arg lat_value must be a vector');
   error(usage);
end
%
arg_info=whos('altitude_value');
if ~strcmp(arg_info.class,'double')
   disp(['Incorrect type of arg altitude_value ' arg_info.class]);
   whos altitude_value
   error(usage);
end
clear arg_info
%
if ~isvector(altitude_value)
   disp('arg altitude_value must be a vector');
   error(usage);
end
%
%
arg_info=whos('station_value');
if ~strcmp(arg_info.class,'cell')
   disp(['Incorrect type of arg station_value ' arg_info.class]);
   whos station_value
   error(usage);
end
clear arg_info
%
% +todo+   disp('arg station_value must be a cell array of strings');
%
%
nb_station=size(station_value,1);
%
% ++ check for size of nb_lat nb_lon nb_station
%
% convert station_value to lower case
station_lower=lower(station_value);
%+todo+ blank
%
% look for identical string in station_value array
result_match=strncmp(station, station_lower, size(station,2));
result_match=transpose(result_match);
%
clear station_lower
%
% test if match found
if (~any(result_match))
   error(['eee : ' mfilename ' : ' 'no match found for station ' station]);
end
%
% test if multiple match
if (size(find(result_match),2) > 1)
   disp([' eee : ' mfilename ' : ' 'list of match indices ' num2str(find(result_match))]);
   for imatch=1:size(find(result_match),2)
       array_match=find(result_match);
       disp([' eee : ' mfilename ' : ' 'match station_value #' , num2str(array_match(imatch))]);
       disp([station_value(array_match(imatch))]);
   end
   error(['eee : ' mfilename ' : ' 'multiple matches for station ' station]);
end
if (size(find(result_match)) == 1)
   lat_station=lat_value(result_match);
   lon_station=lon_value(result_match);
   altitude_station=altitude_value(result_match);
end
%
%whos
%
end

%!demo
%! % To find `barkedji` geolocation::
%! varamma_startup
%! more off
%! [lon_value, lat_value, altitude_value, code_value, station_value, region_value] = read_station();
%! station = 'barkedji';
%! [lon_station, lat_station, altitude_station] = get_station_geolocation(station, lon_value, lat_value, altitude_value, station_value)
%

%!test
%! varamma_startup
%! more off
%! [lon_value, lat_value, altitude_value, code_value, station_value, region_value] = read_station();
%! station = 'barkedji';
%! [lon_station, lat_station, altitude_station] = get_station_geolocation(station, lon_value, lat_value, altitude_value, station_value)
%! assert(lon_station,-14.870)
%! assert(lat_station,15.280)
%! assert(altitude_station,15)
