#! /bin/sh
#+
#
# .. program:: get_trmm.sh
#
# .. _get_trmm.sh:
#
# =======================================
# get_trmm.sh -- get TRMM reference files
# =======================================
#
# SYNOPSIS
# ========
#
# ::
#
#  $ get_trmm.sh [-f] -p product -b yyyymmdd -e yyyymmdd
#
# DESCRIPTION
# ===========
#
# ``get_trmm.sh`` get TRMM reference files from **yyyymmddb** include to **yyyymmdde** excluded.
#
# .. option:: -f
# .. option:: -p product name 3B40
# .. option:: -b beginning date <yyyymmdd>
# .. option:: -e end date <yyyymmdd>
#
# Log file is written on :file:`${PROJECT_LOG}/get_trmm.log.{YYYYMMDDTHHMMSSZ}`
#
# .. only:: man
#
#    Figure is visible on PDF and HTML documents only.
#
# .. only:: html or latex
#
#     .. graphviz::
#
#        digraph get_trmm {
#           graph [
#             rankdir="TB",
#           ]
#
#           trmm_t1_ref [shape=diamond,fontname=Courier,label="loholt1.ipsl.polytechnique.fr:/bdd/TRMM/prod/NCDF/yyyy/prodRT.yyyymmddhh.x.nc"];
#
#           trmm_t1 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/TRMM/prod/yyyy/mm/dd/prodRT.yyyymmddhh.x.nc"];
#
#           log [shape=ellipse,fontname=Courier,label="${PROJECT_LOG}/get_trmm.log.YYYYMMDDTHHMMSSZ"];
#
#           get_trmm [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/get_trmm.sh",
#           label="${PROJECT}/src/get_trmm.sh"];
#
#           {trmm_ref_t1} -> {get_trmm} -> {log trmm_t1}
#
#          }
#
# EXAMPLES
# ========
#
# You don't have any TRMM reference data and you want 3B40  during [20060801, 20060802[, you just have to run this tool ::
#
#  $ get_trmm.sh -p 3B40 -b 20060801 -e 20060802
#
# And look at log file with ::
#
#  $ tlogd.sh get_trmm
#
# and of course on files in ${PROJECT_ID}.
#
# CAUTIONS
# ========
#
# how to know if there is enough place before ?
#
# SEE ALSO
# ========
#
# :ref:`data_precipitation_microwave`
#
# :ref:`varamma_profile.sh`
#
# Next step :
# :ref:`traite_trmm.sh`
#
# TODO
# ====
#
# make it work outside climserv
#
# build/complete catalog
#
# handle -f option
#
# how those :file:`/bdd/TRMM/prod/yyyy/NCDF/*.nc` files have been created
#
# version 5 : hard coded
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - pinsard 20120529T150524Z loholt1.ipsl.polytechnique.fr (Linux)
#
#   * bug fix to handle correctly dates if translation in second on 9 digits
#     (trailing 0 is automaticaly interpreted as an octal number).
#     ex = 20010801
#   * bug fix to handle correctly dates if translation in second of begin
#     and end is not on the same number of digit
#     ex : -b 20010801 -e 20010931
#
# - fplod 20110606T132229Z cratos.locean-ipsl.upmc.fr (Linux)
#
#   * creation from get_msg.sh
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo "www : no specific posix checking"
      date_cmd=date
   ;;
   Darwin)
      set -o posix
      date_cmd=gdate
   ;;
   Linux)
      set -o posix
      date_cmd=date
   ;;
   *)
     set -o posix
   ;;
esac
unset system
#
set -u
#
LANG=POSIX
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command} [-f] -p product -b yyyymmdd -e yyyymmdd"
#
hostname=$(hostname)
#
yyyymmddb_min=20060420
yyyymmdde_max=20081103
#
# default
force=0
product="3B40"
version=5
yyyymmddb=20060801
yyyymmdde=20060802
#
minargcount=6
if [ ${#} -lt ${minargcount} ]
then
   echo "eee : not enought arguments"
   echo "${usage}"
   exit 1
fi
unset minargcount
#
while [ ${#} -gt 0 ]
do
   case ${1} in
      -p)
         product=${2}
         shift
      ;;
      -b)
         # first date to get
         yyyymmddb=${2}
         shift
      ;;
      -e)
         # last date to get
         yyyymmdde=${2}
         shift
      ;;
      -f)
         force=1
      ;;
      -h)
         echo "${usage}"
         exit 0
      ;;
      *)
         # other choice
         echo "eee : unknown option ${1}"
         echo "${usage}"
         exit 1
      ;;
   esac
   # next flag
   shift
done
unset usage
#
# check parameters
# and define associated variables
#
case ${product} in
    3B40)
        prefix="3B40RT."
    ;;
    *)
      echo "${command} : eee : product ${product} argument invalid"
      exit 1
    ;;
esac
#
${date_cmd} -u -d "${yyyymmddb}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
     echo "${command} : eee : yyyymmddb ${yyyymmddb} argument invalid"
     exit 1
fi
unset status_date
#
if [[ "${yyyymmddb}" < "${yyyymmddb_min}" ]]
then
     echo "${command} : eee : yyyymmddb ${yyyymmddb} must be equal or greater than yyyymmddb_min ${yyyymmddb_min}"
     exit 1
fi
#
${date_cmd} -u -d "${yyyymmdde}" > /dev/null
status_date=${?}
if [ ${status_date} -ne 0 ]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} argument invalid"
     exit 1
fi
unset status_date
#
if [[ "${yyyymmdde}" > "${yyyymmdde_max}" ]]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} must be lower or equal to yyyymmdde_max ${yyyymmdde_max}"
     exit 1
fi
#
if [[ "${yyyymmdde}" < "${yyyymmddb}" ]]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} must be greater than yyyymmddb ${yyyymmddb}"
     exit 1
fi
#
if [[ "${yyyymmdde}" = "${yyyymmddb}" ]]
then
     echo "${command} : eee : yyyymmdde ${yyyymmdde} must be greater than yyyymmddb ${yyyymmddb}"
     exit 1
fi
#
# check for ${PROJECT_LOG} definition
if [ "${PROJECT_LOG}" = "" ]
then
   echo "${command} : eee : \${PROJECT_LOG} not defined"
   exit 1
fi
#
# check for ${PROJECT_LOG} existence
if [ ! -d ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not found"
   exit 1
fi
#
# check for permission access on PROJECT_LOG
if [ ! -x ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not reachable"
   exit 1
fi
#
# check for write permission on PROJECT_LOG
if [ ! -w ${PROJECT_LOG} ]
then
   echo "${command} : eee : ${PROJECT_LOG} not writable"
   exit 1
fi
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
unset log_date
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "product=${product}" 1>> ${log}
echo "yyyymmddb=${yyyymmddb}" 1>> ${log}
echo "yyyymmdde=${yyyymmdde}" 1>> ${log}
echo "" 1>> ${log}
#
dirref_base=/bdd/TRMM/${product}
#
# loop over all dates to build URL lists
list_url=""
current=$(${date_cmd} -u -d "${yyyymmddb}" +%s | awk '{printf "%d",$1}')
declare -i current
end=$(${date_cmd} -u -d "${yyyymmdde}" +%s | awk '{printf "%d",$1}')
declare -i end
declare -i delta=10800
while [ ${current} -lt ${end} ]
do
    echo "iii : looking for files of $(${date_cmd} -u -d "1970-01-01 ${current} sec" +%Y%m%dT%H%M)" 1>> ${log}
    yyyymmddhh=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%Y%m%d%H)
    yyyy=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%Y)
    mm=$(${date_cmd} -u -d "1970-01-01 ${current} sec" +%m)
    dirref="${dirref_base}/NCDF/${yyyy}"
    #
    # look for these reference files
    bfile_t1=${prefix}${yyyymmddhh}.${version}.nc
    file_t1=${dirref}/${bfile_t1}
    exist=0
    if [ ! -f ${file_t1} ]
    then
        echo "iii : ${file_t1} not found" >> ${log} 2>&1
    else
        echo "iii : ${file_t1} found" >> ${log} 2>&1
        exist=$(( ${exist} + 1))
    fi
    if [ ${exist} -eq 1 ]
    then
        list_url="${list_url} ${file_t1}"
    fi
    unset yyyymmddhh
    unset yyyy
    unset mm
    unset dd
    unset hhmn
    unset dirref
    #
    # next time step
    current=$((${current} + ${delta}))
done
unset current
unset end
#
if [ "${list_url}" = "" ]
then
   echo "iii : no files founds" >> ${log} 2>&1
else
    #
    # if file is not already in ${PROJECT_ID}, get it
    for url in ${list_url}
    do
        burl=$( basename ${url})
        after_prefix=${burl#${prefix}}
        url_yyyymmddhh=${after_prefix%\.${version}\.*}
        yyyy=${url_yyyymmddhh:0:4}
        mm=${url_yyyymmddhh:4:2}
        dd=${url_yyyymmddhh:6:2}
        file=${PROJECT_ID}/TRMM/${product}/${yyyy}/${mm}/${dd}/$(basename ${url})
        if [ ! -f ${file} ]
        then
           loc=$(dirname ${file})
           if [ ! -d ${loc} ]
           then
              mkdir -p ${loc}
              echo "iii : adding ${loc}" >> ${log}
           fi
           ln -s ${url} ${file}
           echo "iii : adding ${file}" >> ${log}
        else
           echo "iii : ${file} exists" >> ${log}
        fi
        unset yyyymmddhh
        unset yyyy
        unset mm
        unset dd
        unset burl
        unset after_prefix
        unset loc
    done
    unset file
    unset url
fi
unset list_url
#
unset command
unset log
unset hostname
unset usage
#
unset date_cmd
#
# end
#++set
exit 0
