#! /bin/sh
#+
#
# .. _paper01_pre.sh:
#
# .. program:: paper01_pre.sh
#
# ==============
# paper01_pre.sh
# ==============
#
# ------------------------------
# data prerequisite for paper #1
# ------------------------------
#
# SYNOPSIS
# ========
#
# ::
#
#  $ paper01_pre.sh
#
# DESCRIPTION
# ===========
#
# Put in ${PROJECT_ID} all the data files necessary to plot all the figures
# for paper1.
#
# The set of reference files is described in
# http://www.locean-ipsl.upmc.fr/~fplod/varamma/notes/fr/one/varamma.html#data
#
# Once this tool executed :ref:`paper01.pro` can be launched.
#
# Log file is written on :file:`${PROJECT_LOG}/paper01_pre.log.{YYYYMMDDTHHMMSSZ}`
#
# .. only:: man
#
#    Figure is visible on PDF and HTML documents only.
#
# .. only:: html or latex
#
#     .. graphviz::
#
#        digraph paper01 {
#           graph [
#           rankdir="TB",
#           ]
#
#           varamma_ref [shape=ellipse,fontname=Courier,label="cx.++.nc"];
#           olr_ref [shape=diamond,fontname=Courier,label="${PROJECT_ID}/olr.day.mean.nc"];
#           
#           varamma_t1 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/cx.climato.nc"];
#           olr_t1 [shape=ellipse,fontname=Courier,label="${PROJECT_ID}/olr.day.mean_yyyy_ng.nc"];
#           
#           figures [shape=ellipse,fontname=Courier,label="${PROJECT_OD}/figurexx.png"];
#           
#           paper01_pre [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/paper01_pre.sh"
#           label="${PROJECT}/src/paper01_pre.sh"];
#           paper01 [shape=box,
#           fontname=Courier,
#           color=blue,
#           URL="http://forge.ipsl.jussieu.fr/varamma/browser/trunk/src/paper01.pro"
#           label="${PROJECT}/src/paper01.pro"];
#           
#           {varamma_ref} -> {paper01_pre} -> {varamma_t1}
#           {olr_ref} -> {paper01_pre} -> {olr_t1}
#           {varamma_t1} -> {paper01} -> {figures};
#           {olr_t1} -> {paper01} -> {figures};
#          }
#
# TODO
# ====
#
# .. todo::
#
#   add dataset parameter
#
# ++ les fichiers de climato sont produits  partir des fichiers de rfrence
# donc il faudrait plutt lancer clim++ avant ou dedans
#
# ++ quels sont les fichiers de rfrences AMSU
#
# ++ comment a marche sur climserv
#
# CAUTIONS
# ========
#
# Does'nt work on zeus because of UDUnits library problems
#
# SEE ALSO
# ========
#
# :ref:`paper01.pro`
#
# :ref:`varamma_profile.sh`
#
# :ref:`olr_split.sh`
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# - fplod 20100702T081256Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add graph (from varamma/notes/varamma_etape5.dot)
#
# - fplod 2009-05-27T10:20:28Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add ECMWF operational and ERA40 files
#   * prepare dataset parameter (see get* variable)
#   * handle wget status
#   * handle terminology heterogeneity in ftp://ftp.climserv.ipsl.polytechnique.fr/opera/GLOBAL_1125/4xdaily/AN_PL/ :
#      before 2006 ``param``.``yyyymm``.aph.nc
#      from 2006 ``param``.``yyyymm``.aph.GLOBAL_1125.nc
#
# - pinsard 2009-04-01T13:07:53Z camelot.ipsl.polytechnique.fr (Linux)
#
#   * log
#   * POSIX
#
# - fplod 2008-08-13T12:27:41Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * add OLR reference file and yearly-afratl files production
#
# - fplod 2008-08-12T13:55:32Z aedon.locean-ipsl.upmc.fr (Darwin)
#
#   * creation. not finish
#
#-
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo " www : no specific posix checking"
   ;;
   *)
     set -o posix
   ;;
esac
unset system
#
LANG=POSIX
#
case $(hostname) in
   zeus.locean-ipsl.upmc.fr|dedale.locean-ipsl.upmc.fr)
      echo "eee : pb on UDUnits library on zeus"
      echo "eee : contact system team"
      exit 1
   ;;
esac
#
command=$(basename ${0})
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
#
usage=" Usage : ${command}"
#
hostname=$(hostname)
#
# default ++
getamsu=0
getolr=0
getecmwf=1
getecmwf_opera=1
getecmwf_era40=1
#
set -u
#
# check for ${PROJECT_LOG} definition
if [ "${PROJECT_LOG}" = "" ]
then
   echo " eee : \${PROJECT_LOG} not defined"
   exit 1
fi
#
# check for ${PROJECT_LOG} existence
if [ ! -d ${PROJECT_LOG} ]
then
   echo " eee : ${PROJECT_LOG} not found"
   exit 1
fi
#
# check for permission access on PROJECT_LOG
if [ ! -x ${PROJECT_LOG} ]
then
   echo " eee : ${PROJECT_LOG} not reachable"
   exit 1
fi
#
# check for write permission on PROJECT_LOG
if [ ! -w ${PROJECT_LOG} ]
then
   echo " eee : ${PROJECT_LOG} not writable"
   exit 1
fi
#
log=${PROJECT_LOG}/$(basename ${0} .sh).log.${log_date}
echo "[Context]" 1>> ${log}
echo "command=$(basename ${0})" 1>>${log}
echo "hostname=${hostname}" 1>> ${log}
echo "runtime=${log_date}" 1>> ${log}
echo "log=${log}" 1>> ${log}
echo "" 1>> ${log}
echo "[Parameters]" 1>> ${log}
echo "getamsu=${getamsu}" 1>> ${log}
echo "getolr=${getolr}" 1>> ${log}
echo "getecmwf_opera=${getecmwf_opera}" 1>> ${log}
echo "getecmwf_era40=${getecmwf_era40}" 1>> ${log}
echo "" 1>> ${log}
#
#++ debug
if [ ${getamsu} -eq 1 ]
then
   # AMSU
   list_channel="a4 a5 b5 b3"
   list_type="year climato"
   list_year="2006"
   refloc="/usr/home/lelod/AMSU/"
   # ++ seulement valable en interne locean
   for channel in ${list_channel}
   do
      for type in ${list_type}
      do
         case ${type} in
            year)
               refloc="/usr/home/lelod/AMSU/"
               for iyear in ${list_year}
               do
                  cyear=$(printf "%4.4d" ${iyear})
                  fileref=${channel}.an${cyear}.nc
               done
            ;;
            climato)
               fileref=${channel}.climato.nc
            ;;
            *)
               echo "eee : wrong file type" 1>> ${log}
               exit 1
            ;;
         esac
         # ++ test if exists
         if [ ! -f ${refloc}/${fileref} ]
         then
            echo "eee : ${refloc}/${fileref} unavailable" 1>> ${log}
            exit 1
         fi
         if  [ -f ${PROJECT_ID}/${fileref} ]
         then
            echo "iii : ${PROJECT_ID}/${fileref} exist" 1>> ${log}
            echo "iii : nothing done"
         else
            ln -s ${refloc}/${fileref} ${PROJECT_ID}/
         fi
      done
   done
fi

# OLR
if [ ${getolr} -eq 1 ]
then
   fileref=olr.day.mean.nc
   locref=ftp://ftp.climserv.ipsl.polytechnique.fr/noaa-olr/
   if  [ -f ${PROJECT_ID}/${fileref} ]
   then
      echo "iii : ${PROJECT_ID}/${fileref} exist" 1>> ${log}
      echo "iii : nothing done" 1>> ${log}
   else
      wget -P ${PROJECT_ID} ${locref}/${fileref} 1>> ${log} 2>&1
      wget_status=${?}
      if [ ${wget_status} -ne 0 ]
      then
         echo "eee : ${locref}/${file} not found" >> ${log} 2>&1
         # exit 1 #++
      else
         echo "iii : ${locref}/${file} found" >> ${log} 2>&1
      fi
   fi
fi
#
# yearly-afratl files production
iyearmin=2006
iyearmax=2006
iyear=${iyearmin}
list_file=" "
nfile=0
# have we all then yearly-afratl ?
# ++ et si ils sont l est-ce que c'est la bonnne version
while [ ${iyear} -le ${iyearmax} ]
do
   cyear=$(printf "%4.4d" ${iyear})
   list_file="${list_file} ${PROJECT_ID}/olr.day.mean_${cyear}_ng.nc"
   iyear=$(( ${iyear} + 1 ))
   nfile=$(( ${nfile} + 1 ))
done
#
nfound=0
for file in ${list_file}
do
   if [ ! -f ${file} ]
   then
      echo " iii : ${file} not found" 1>> ${log}
   else
      nfound=$(( ${nfound} + 1 ))
   fi
done
if [ ${nfound} -ne ${nfile} ]
then
   echo " iii : production of ${list_file}" 1>> ${log}
   olr_split.sh -f
   # ++ ok ?
fi
#
# ++climato

# ECMWF
if [ ${getecmwf_opera} -eq 1 ]
then
   dirref="/bdd/OPERA/NETCDF/GLOBAL_1125/4xdaily/AN_PL/" # ++ climserv local
   locref=ftp://ftp.climserv.ipsl.polytechnique.fr/opera/GLOBAL_1125/4xdaily/AN_PL/
   list_url=""
   list_param="geopt"
   for param in ${list_param}
   do
      iyearmin=2002
      iyearmax=2008
      iyear=${iyearmin}
      while [ ${iyear} -le ${iyearmax} ]
      do
         cyear=$(printf "%4.4d" ${iyear})
         imonthmin=1
         imonthmax=12
         imonth=${imonthmin}
         while [ ${imonth} -le ${imonthmax} ]
         do
            cmonth=$(printf "%2.2d" ${imonth})
            if [ ${iyear} -le 2005 ]
            then
               list_url="${list_url} ${locref}/${cyear}/${param}.${cyear}${cmonth}.aph.nc"
            else
               list_url="${list_url} ${locref}/${cyear}/${param}.${cyear}${cmonth}.aph.GLOBAL_1125.nc"
            fi
            imonth=$(( ${imonth} + 1 ))
         done
         iyear=$(( ${iyear} + 1 ))
       done
    done
    for url in ${list_url}
    do
      file=${PROJECT_ID}/$(basename ${url})
      if [ ! -f ${file} ]
      then
         wget --no-verbose -P ${PROJECT_ID} ${url} >> ${log} 2>&1
         wget_status=${?}
         if [ ${wget_status} -ne 0 ]
         then
            echo "eee : ${url} not found" >> ${log} 2>&1
            # exit 1 #++
         else
            echo "iii : ${url} found" >> ${log} 2>&1
         fi
      else
         echo "iii : ${file} exists" >> ${log}
      fi
   done
fi
if [ ${getecmwf_era40} -eq 1 ]
then
   list_url=""
   locref=ftp://ftp.climserv.ipsl.polytechnique.fr/era40/4xdaily/AN_PL/
   list_param="z"
   for param in ${list_param}
   do
      iyearmin=2000
      iyearmax=2002
      iyear=${iyearmin}
      while [ ${iyear} -le ${iyearmax} ]
      do
         cyear=$(printf "%4.4d" ${iyear})
         if [ ${iyear} -le 2001 ]
         then
            imonthmin=1
            imonthmax=12
         else
            imonthmin=1
            imonthmax=08
         fi
         imonth=${imonthmin}
         while [ ${imonth} -le ${imonthmax} ]
         do
            cmonth=$(printf "%2.2d" ${imonth})
            list_url="${list_url} ${locref}/${cyear}/${param}.${cyear}${cmonth}.aph.nc"
            imonth=$(( ${imonth} + 1 ))
         done
         iyear=$(( ${iyear} + 1 ))
      done
   done
   for url in ${list_url}
   do
      file=${PROJECT_ID}/$(basename ${url})
      if [ ! -f ${file} ]
      then
         wget --no-verbose -P ${PROJECT_ID} ${url} >> ${log} 2>&1
         wget_status=${?}
         if [ ${wget_status} -ne 0 ]
         then
            echo "eee : ${url} not found" >> ${log} 2>&1
            # exit 1 #++
         else
            echo "iii : ${url} found" >> ${log} 2>&1
         fi
      else
        echo "iii : ${file} exists" >> ${log}
      fi
   done
fi
#
# end
set
exit 0
