function [west_value, east_value, north_value, south_value, zi_code, zi_description]=read_zi()

%READ_ZI fill zone of interest associated arrays lat, lon, code and description
%in file :file:`${PROJECT_ID}/maps/varamma_zi.csv`

%
%+
%
% =========
% read_zi.m
% =========
%
% .. function:: read_zi()
%
% DESCRIPTION
% ===========
%
% read zone of interest data in a
% file :file:`${PROJECT_ID}/maps/varamma_zi.csv`
%
%    :param west_value: west most longitudes
%    :type west_value: 1d array of doubles
%
%    :param east_value: east most longitudes
%    :type east_value: 1d array of doubles
%
%    :param north_value: north most latitudes
%    :type north_value: 1d array of doubles
%
%    :param south_value: south most latitudes
%    :type south_value: 1d array of doubles
%
%    :param zi_code: codes of the zone of interest
%    :type zi_code: 1D cell array of strings
%
%    :param zi_description: descriptions of the zone of interest
%    :type zi_description: 1D cell array of strings
%
% return associated arrays lat, lon, code and description
%
% EXAMPLES
% ========
%
% To read :file:`${PROJECT_ID}/maps/varamma_zi.csv`:
%
% see demo 1
%
% A file :file:`${PROJECT_ID}/maps/varamma_zi_write_zi.csv` can be written
% with data we just read::
%
%  octave> result=write_zi(zi, west_value, east_value, north_value, south_value, zi_code, zi_description);
%
% Files comparison might help detecting problems (either on files or in programs involved)::
%
%  $ diff ${PROJECT_ID}/maps/varamma_zi.csv ${PROJECT_ID}/maps/varamma_zi_write_zi.csv
%
% SEE ALSO
% ========
%
% :ref:`zones`
%
% :func:`simul_zi`
% :func:`write_zi`
% :func:`plot_zi`
%
% :func:`recup_camp`
%
% TODO
% ====
%
% suppress " from zi_description
%
% EVOLUTIONS
% ==========
%
% $Id$
% $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/read_zi.m $
%
% - fplod 20110629T071900Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * creation wih csv reading usage becase octave 3.4 do not provide xmlread !
%
%-
%
global PROJECT_ID
%
usage='[west_value, east_value, north_value, south_value, zi_code, zi_description]=read_zi()';
%
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage);
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
% build zi filename to be read
fullfilename=[PROJECT_ID 'maps/' 'varamma_zi.csv'];
disp(['iii : opening for reading ', fullfilename]);
% opening file
[fid,message]=fopen(fullfilename,'r');
% test if fullfilename exists
if (fid == -1)
    disp(message)
    error([ fullfilename ' not exist'])
end
clear fullfilename
clear message
% the maximum of zi is set to 30
nb_zi_max = 30;
%
% preallocation of zi_description array to missing value
zi_description=repmat({'NaN'},nb_zi_max,1);
%
% preallocation of zi_code array to missing value NaN
zi_code=repmat({'NaN'},nb_zi_max,1);
%
% preallocation of north_value, south_value array to missing value NaN
north_value=zeros(nb_zi_max,1,'double');
north_value(:)=NaN;
south_value=zeros(nb_zi_max,1,'double');
south_value(:)=NaN;
% preallocation of west_value, east_value array to missing value NaN
west_value=zeros(nb_zi_max,1,'double');
west_value(:)=NaN;
east_value=zeros(nb_zi_max,1,'double');
east_value(:)=NaN;
%
% read file
%
% first line contains "code,description,north,south,east,west"
%
% get next line as a string
header_line = fgetl(fid);
% +todo+ check header
clear header_line
%
% reading data from file (from second line till end of file)
index_line_data=1;
%
while (feof(fid)~= 1)
  data_line = fgetl(fid);
  % loop to handle eahc item on the data line (comma separated value)
  index_item=1;
  while ( ~isempty(data_line) )
     % parse next column label
     [item,data_line] = strtok(data_line,',');
     if (index_item == 1 )
       zi_code(index_line_data)=cellstr(item);
     elseif (index_item == 2)
       zi_description(index_line_data)=cellstr(item);
     elseif (index_item == 3)
       north_value(index_line_data)=str2double(item);
     elseif (index_item == 4)
       south_value(index_line_data)=str2double(item);
     elseif (index_item == 5)
       east_value(index_line_data)=str2double(item);
     elseif (index_item == 6)
       west_value(index_line_data)=str2double(item);
     else
       error([ 'invalid data line (too many items) : ' data_line item]);
     end
     clear item
     % increase index of item
     index_item = index_item + 1;
  end
  % check for number of item in current data line
  if (index_item < 6)
     error([ 'invalid data line (missing items) :' data_line])
  end
  index_line_data=index_line_data+1;
  clear data_line
  clear index_item
end
if (index_line_data > nb_zi_max+1)
  error([' need to increase nb_zi_max up to ' num2str(index_line_data) ]);
end
%
clear index_line_data
%
fclose(fid);
clear fid
%
% remove extra data NaN values due to preallocation
% criteria = when zi_description is not 'NaN'
missing_zi_indices=find(ismember(zi_description, 'NaN')==1);
nb_zi=min(missing_zi_indices)-1;
zi_code=zi_code(1:nb_zi);
zi_description=zi_description(1:nb_zi);
north_value=north_value(1:nb_zi);
south_value=south_value(1:nb_zi);
west_value=west_value(1:nb_zi);
east_value=east_value(1:nb_zi);
%
clear nb_zi_max
clear nb_zi
%
%++whos
%
result=0;
end

%!demo
%! clear all
%! close all
%! varamma_startup
%! more off
%! [west_value, east_value, north_value, south_value, zi_code, zi_description ] = read_zi()
