function [lon_value, lat_value, datejul_value, datestr_value, msg_tb108]=simul_msg(index_simulation)

%SIMUL_MSG fill array tb108 3D array and associated arrays lat, lon, date
%with simulated data

%
%+
%
% ===========
% simul_msg.m
% ===========
%
% .. function:: simul_msg(index_simulation)
%
% DESCRIPTION
% ===========
%
%    :param index_simulation: index of simulation
%    :type index_simulation: uint8
%    :raise index_simulation: required
%
% Charge en mmoire un tableau 3D simul **msg_tb108** de tb108
% dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
%
% Simulation #1
%    la zone gographique [20W,10W] [10N,20N] avec un point tous les 5 en
%    latitude et 5 en longitude et dans la zone temporelle 20060726-20060727
%    avec un point ts les 1/4 d'heure
%
% Simulation #2
%    la zone gographique [++W,++W] [++N,++N] avec 928 points en latitude
%    et 1856 points en longitude dans la zone temporelle 20060726-20060731
%    avec un point ts 1/4 d'heure
%
% Simulation #3
%    la zone gographique [20W,10W] [10N,20N] avec un point tous les 5 en
%    latitude et 5 en longitude et dans la zone temporelle 20060726-20060727
%
% Les longitudes sont stockes dans le tableau **lon_value**.
%
% Les latitudes sont stockes dans le tableau **lat_value**.
%
% Les dates au format `yyyymmddhhmn` sont stocks dans le tableau **datestr_value**.
% et les dates en jour julien sont stockes dans **datejul_value**.
%
% EXAMPLES
% ========
%
% From scratch to create short array of tb108 and associated arrays lat, long
% and datestr (4 days) :
%
% see demo 1
%
% To plot the grid::
%
%   octave> showgrid(lon_value, lat_value);
%
% From scratch to create long array of tb108 and associated arrays lat, long
% and datestr:
%
% see demo 2
%
% To plot the grid::
%
%   octave> result=showgrid(lon_value, lat_value);
%
% From scratch to create short array of tb108 and associated arrays lat, long
% and datestr (1 day) :
%
% see demo 3
%
% SEE ALSO
% ========
%
% :ref:`data_msg`
%
% :func:`MSGread`
%
% TODO
% ====
%
% des valeurs de tb108 plus ralistes y compris des NaN
%
% fix octave pb for simulation #2::
%
%   error: memory exhausted or requested size too large for range of Octave's index type -- trying to return to prompt
%
% too long for simulation #2 using matlab
%
% returned values when error
%
% use in other MSG tools
%
% EVOLUTIONS
% ==========
%
% $Id: simul_msg.m 199 2011-03-04 10:11:00Z pinsard $
%
% $URL$
%
% - fplod 20110816T073113Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * replace int8 by uint8 for integer parameters
%
% - fplod 20110621T075258Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * suppression d'un case en trop de datejul_value
%   * passage de datejul_value de vectuer ligne  vecteur colonne pour
%     tre plus proche des sorties de MSGread
%
% - fplod 20110609T124035Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * boite  l'ouest !
%
% - fplod 20110609T081126Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add datejul_value output
%   * rearrange epsat_value dimension
%     dimension 1 : temps, dimension 2 : lon,  dimension 3 : lat
%   * revision of init of simulation
%   * add demo 3
%
% - fplod 20110307T164521Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * add demo with only one day (to emphase possible trouble due to hard
%     coded values in :func:`intensityMSG_day`)
%
% - fplod 20110307T163822Z aedon.locean-ipsl.upmc.fr (Darwin)
%
%   * correction to have 96 time step / day (not 97 !)
%   * correction on the time dimension of msg_tb108 (not numel(datestr_value) !
%
% - fplod 20110304
%
%   * creation
%-
%
result=-1;
%
usage='[lon_value, lat_value, datejul_value, datestr_value, msg_tb108]=simul_msg(index_simulation)';
if nargin~=nargin(mfilename)
   disp(['Incorrect number of input arguments ' num2str(nargin)]);
   error(usage)
end
%
if nargout ~= nargout(mfilename)
   disp(['Incorrect number of output arguments ' num2str(nargout)]);
   error(usage);
end
%
arg_info=whos('index_simulation');
if ~strcmp(arg_info.class,'uint8')
   disp(['Incorrect type of arg index_simulation']);
   whos index_simulation
   error(usage);
end
clear arg_info
%
yyyymin_value=2006;
yyyymax_value=2006;
mmmin_value=07;
mmmax_value=07;
datestr_delta=(datenum(2000,1,2)-datenum(2000,1,1))/96.;
% dfinition de la zone gographique : les coins en degr et les rsolutions
lat_delta = 5.;
lon_delta = 5.;
if (index_simulation == 1)
   ddmin_value=26;
   ddmax_value=26;
   lonmin_value=-25;
   lonmax_value=+25;
   latmin_value=-5.;
   latmax_value=20.;
elseif (index_simulation == 2)
   ddmin_value=26;
   ddmax_value=31;
   lonmin_value=-25;
   lonmax_value=+25;
   latmin_value=-5.;
   latmax_value=20.;
elseif (index_simulation == 3)
   ddmin_value=26;
   ddmax_value=26;
   lonmin_value=-25;
   lonmax_value=+25;
   latmin_value=-5.;
   latmax_value=20.;
   lat_delta = 5.;
else
   error(['eee : unknown simulation ' num2str(index_simulation)]);
end
clear index_simulation
%
% cration du tableau des longitudes
lon_value=transpose(lonmin_value:lon_delta:lonmax_value);
clear lonmin_value
clear lonmax_value
clear lon_delta
%
% cration du tableau des latitudes
lat_value=transpose(latmin_value:lat_delta:latmax_value);
clear latmin_value
clear latmax_value
clear lat_delta
%
datejul_value=datenum(yyyymin_value,mmmin_value,ddmin_value):datestr_delta:datenum(yyyymax_value,mmmax_value,ddmax_value+1);
datejul_value=datejul_value(1:end-1);
clear yyyymin_value
clear yyyymax_value
clear mmmin_value
clear mmmax_value
clear ddmin_value
clear ddmax_value
clear datestr_delta
%
% conversion datenum (unit octave/matlab) en format "yyyymmddhhmn"
datestr_value=datestr(datejul_value,'yyyymmddHHMM');
%
% row to column
datejul_value=transpose(datejul_value);
;
% cration de tableau tb108
msg_tb108=zeros(size(datestr_value,1),numel(lon_value),numel(lat_value));
msg_tb108(:,:,:)=NaN;
for index_datestr=1:size(datestr_value,1)
    for index_lon=1:numel(lon_value)
        for index_lat=1:numel(lat_value)
            msg_tb108(index_datestr,index_lon,index_lat)=(index_datestr+index_lon)/100. + (index_datestr+index_lat)/100.;
        end
   end
end
clear index_lat
clear index_lon
clear index_datestr
%
% whos
%
result=0;
%
end

%!demo
%! % From scratch to create short array of tb108 and associated arrays lat, long
%! % and datestr::
%! varamma_startup
%! more off
%! index_simulation = uint8(1);
%! [lon_value, lat_value, datejul_value, datestr_value, msg_tb108] = simul_msg(index_simulation)

%!demo
%! % From scratch to create long array of tb108 and associated arrays lat, long
%! % and datestr::
%! varamma_startup
%! more off
%! index_simulation = uint8(2);
%! [lon_value, lat_value, datejul_value, datestr_value, msg_tb108] = simul_msg(index_simulation);

%!demo
%! % From scratch to create long array of tb108 and associated arrays lat, long
%! % and datestr++ demo 3::
%! varamma_startup
%! more off
%! index_simulation = uint8(3);
%! [lon_value, lat_value, datejul_value, datestr_value, msg_tb108] = simul_msg(index_simulation);
%! lon_value
%! lat_value
