#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

__docformat__ = 'reStructuredText'
__autodoc__ = ['write_zi']

import os
import sys
import csv

def write_zi(west_value, east_value, north_value, south_value, zi_code, zi_description):

    """

    ========
    write_zi
    ========

    .. :py:function:: write_zi(west_value, east_value, north_value, south_value, zi_code, zi_description)

    DESCRIPTION
    ===========

    Write in a file :file:`${PROJECT_ID}/maps/varamma_zi_write_zi_py.csv`

    Parameters
    ----------

    west_value : array_like
        west most longitudes

    east_value : array_like
        east most longitudes

    north_value : array_like
        north most latitudes

    south_value : array_like
        south most latitudes

    zi_code : array_like of strings
        codes of the zone of interest

    zi_description: array_like of strings
        descriptions of the zone of interest

    Returns
    -------

    result : int
       1 if ok

    Raises
    ------

    Missing parameters

    EXAMPLES
    ========

    From scratch to write some simulated zi data in
    :file:`${PROJECT_ID}/maps/varamma_zi_write_zi_py.csv`:

    >>> # From scratch to write some simulated zi data in
    >>> # :file:`${PROJECT_ID}/maps/varamma_zi_write_zi_py.csv`::
    >>> # ++ matlab varamma_startup
    >>>
    >>> from simul_zi import simul_zi
    >>> index_simulation = 1
    >>> (west_value, east_value, north_value, south_value, zi_code, zi_description) = simul_zi(index_simulation)
    >>> result = write_zi(west_value, east_value, north_value, south_value, zi_code, zi_description)
    iii : opening for writing /usr/work/incas/fplod/varamma_d//maps/varamma_zi_write_zi_py.csv


    From real file :file:`${PROJECT_ID}/maps/varamma_zi.csv`:

    >>> from read_zi import read_zi
    >>> (west_value, east_value, north_value, south_value, zi_code, zi_description) = read_zi()
    iii : opening for reading /usr/work/incas/fplod/varamma_d//maps/varamma_zi.csv
    >>> result = write_zi(west_value, east_value, north_value, south_value, zi_code, zi_description)
    iii : opening for writing /usr/work/incas/fplod/varamma_d//maps/varamma_zi_write_zi_py.csv

    SEE ALSO
    ========

    :ref:`zones`

    py:func:`simul_zi`
    py:func:`read_zi`

    TODO
    ====

    coding rules

    connexion with define_area

    get rid of matlab stuff

    avoid over writing

    remove formatting (keept for learning issue)

    include in sphinx processing
 
    cf. http://forums.arcgis.com/threads/37866-python-script-for-batch-coversion-from-dbf-to-csv-files

    cf. http://help.arcgis.com/en/arcgisdesktop/10.0/help/index.html#//0017000000n4000000

    EVOLUTIONS
    ==========

    $Id$

    $URL: svn+ssh://pinsard@forge.ipsl.jussieu.fr/ipsl/forge/projets/varamma/svn/trunk/src/write_zi.py $

    - fplod 20110907T090235Z cratos (Linux)

      * add test from real file

    - fplod 20110906T125953Z aedon.locean-ipsl.upmc.fr (Darwin)

      * correction of test 1 to avoid Expecting nothing
      * suppress quote around numeric
      * better usage of format
        see http://docs.python.org/library/string.html#formatstrings
        but not used ... because of interaction with QUOTE_NONNUMERIC

    - fplod 20110816T151904Z aedon.locean-ipsl.upmc.fr (Darwin)

      * still draft but output file is created

    - fplod 20110802T155839Z aedon.locean-ipsl.upmc.fr (Darwin)

      * creation from write_zi.m to learn csv python writing
        see http://www.commentcamarche.net/faq/2382-python-lire-et-ecrire-des-fichiers-csv
        and http://www.chicoree.fr/w/Fichiers_CSV_en_Python/
        and http://www.doughellmann.com/PyMOTW/csv/

    """

    result = -1
    #
    usage = 'result = write_zi(west_value, east_value, north_value, south_value, zi_code, zi_description)'
    #
    # ++ matlabif nargin~=6
    # ++ matlab   disp(['Incorrect number of arguments ' num2str(nargin)])
    # ++ matlab   error(usage)
    # ++ matlabend
    #
    # ++ matlabarg_info=whos('west_value')
    # ++ matlabif ~strcmp(arg_info.class,'double')
    # ++ matlab   disp(['Incorrect type of arg west_value' arg_info.class])
    # ++ matlab   whos west_value
    # ++ matlab   error(usage)
    # ++ matlabend
    #
    # ++ matlab if ~isvector(west_value)
    # ++ matlab    disp('arg west_value must be a vector')
    # ++ matlab    error(usage)
    # ++ matlab end
    #
    # ++ matlab arg_info=whos('east_value')
    # ++ matlab if ~strcmp(arg_info.class,'double')
    # ++ matlab    disp(['Incorrect type of arg east_value ' arg_info.class])
    # ++ matlab    whos east_value
    # ++ matlab    error(usage)
    # ++ matlab end
    # ++ matlab #
    # ++ matlab if ~isvector(east_value)
    # ++ matlab    disp('arg east_value must be a vector')
    # ++ matlab    error(usage)
    # ++ matlab end
    # ++ matlab #
    # ++ matlab arg_info=whos('north_value')
    # ++ matlab if ~strcmp(arg_info.class,'double')
    # ++ matlab    disp(['Incorrect type of arg north_value' arg_info.class])
    # ++ matlab    whos north_value
    # ++ matlab    error(usage)
    # ++ matlab end
    #
    # ++ matlab if ~isvector(north_value)
    # ++ matlab    disp('arg north_value must be a vector')
    # ++ matlab    error(usage)
    # ++ matlab end
    # ++ matlab #
    # ++ matlab arg_info=whos('south_value')
    # ++ matlab if ~strcmp(arg_info.class,'double')
    # ++ matlab    disp(['Incorrect type of arg south_value ' arg_info.class])
    # ++ matlab    whos south_value
    # ++ matlab    error(usage)
    # ++ matlab end
    #
    # ++ matlab if ~isvector(south_value)
    # ++ matlab    disp('arg south_value must be a vector')
    # ++ matlab    error(usage)
    # ++ matlab end
    #
    # ++ matlab arg_info=whos('zi_code')
    # ++ matlab if ~strcmp(arg_info.class,'cell')
    # ++ matlab    disp(['Incorrect type of arg zi_code ' arg_info.class])
    # ++ matlab    whos zi_code
    # ++ matlab    error(usage)
    # ++ matlab end
    #
    # +todo+   disp('arg zi_code must be a cell array of strings')
    #
    #
    # ++ matlab arg_info=whos('zi_description')
    # ++ matlab if ~strcmp(arg_info.class,'cell')
    # ++ matlab    disp(['Incorrect type of arg zi_description ' arg_info.class])
    # ++ matlab    whos zi_description
    # ++ matlab    error(usage)
    # ++ matlab end
    #
    # +todo+   disp('arg zi_description must be a cell array of strings')
    #
    # ++ matlab # check for size of nb_lat nb_lon nb_zi
    nb_zi = len(zi_description)
    #
    # ++ matlab test_consistent = isequal(len(west_value), len(east_value), len(north_value, south_value), len(zi_code), len(zi_description))
    # ++ matlab   otherwise
    # ++ matlab      error('unknown application running')
    # ++ matlab end
    test_consistent = 1 # force++
    if not test_consistent:
        print ('eee : inconsistent dimensions of west_value, east_value, north_value, south_value, zi_code and zi_description')
        west_value
        east_value
        north_value, south_value
        zi_code
        zi_description
        print (usage)
        sys.exit(0)
    #
    project_id_env = os.environ['PROJECT_ID']

    # build ASCII filename to be written
    # ++ replace 'write_zi' by the name of this function
    fullfilename = project_id_env + '/maps/' + 'varamma_zi' + '_' + 'write_zi' + '_py' + '.csv'
    print('iii : opening for writing %s' % (fullfilename))
    fid = open(fullfilename, "wb")
    fid_csv = csv.writer(fid,quoting=csv.QUOTE_NONNUMERIC)
    #
    # +todo+ check opening ok
    #
    # write header
    fid_csv.writerow(["code", "description", "north", "south", "east", "west"])
    #
    # write data
    #
    sep = ','
    format_lat = '6.3f'
    format_lon = '7.3f'
    # loop on zi to write each data line
    for index_zi in range(0, nb_zi):
        description_trim=zi_description[index_zi]
        code_trim=zi_code[index_zi]
        west_trim="{0:{format_lon}}".format(west_value[index_zi],format_lon=format_lon)
        east_trim="{0:{format_lon}}".format(east_value[index_zi],format_lon=format_lon)
        north_trim="{0:{format_lat}}".format(north_value[index_zi],format_lat=format_lat)
        south_trim="{0:{format_lat}}".format(south_value[index_zi],format_lat=format_lat)
        fid_csv.writerow(
           (
           '%s' % zi_code[index_zi], 
           '%s' % zi_description[index_zi],
            north_value[index_zi], 
            south_value[index_zi],  
            east_value[index_zi], 
            west_value[index_zi])
        )
    #
    fid.close()
    #
    #++whos
    result = 0
    #

# Run main, if called from the command line
if __name__ == '__main__':
    import doctest
    doctest.testmod()
